@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -52,7 +52,7 @@ __all__ = ("RedshiftDataAPIServiceClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -69,7 +69,7 @@ class Exceptions:
 
 class RedshiftDataAPIServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html)
     """
 
@@ -86,7 +86,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         *,
         ClusterIdentifier: str,
         Database: str,
-        Sqls: List[str],
+        Sqls: Sequence[str],
         DbUser: str = None,
         SecretArn: str = None,
         StatementName: str = None,
@@ -96,7 +96,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         Runs one or more SQL statements, which can be data manipulation language (DML)
         or data definition language (DDL).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Client.batch_execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Client.batch_execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#batch_execute_statement)
         """
 
@@ -104,7 +104,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#can_paginate)
         """
 
@@ -112,7 +112,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         Cancels a running query.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Client.cancel_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Client.cancel_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#cancel_statement)
         """
 
@@ -121,7 +121,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         Describes the details about a specific instance when a query was run by the
         Amazon Redshift Data API.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#describe_statement)
         """
 
@@ -141,7 +141,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         Describes the detailed information about a table from metadata in the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#describe_table)
         """
 
@@ -152,7 +152,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         Database: str,
         Sql: str,
         DbUser: str = None,
-        Parameters: List["SqlParameterTypeDef"] = None,
+        Parameters: Sequence["SqlParameterTypeDef"] = None,
         SecretArn: str = None,
         StatementName: str = None,
         WithEvent: bool = None
@@ -161,21 +161,21 @@ class RedshiftDataAPIServiceClient(BaseClient):
         Runs an SQL statement, which can be data manipulation language (DML) or data
         definition language (DDL).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Client.execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Client.execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#execute_statement)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#generate_presigned_url)
         """
 
@@ -185,7 +185,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         Fetches the temporarily cached result of an SQL statement.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Client.get_statement_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Client.get_statement_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#get_statement_result)
         """
 
@@ -202,7 +202,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         List the databases in a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_databases)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_databases)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#list_databases)
         """
 
@@ -221,7 +221,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         Lists the schemas in a database.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_schemas)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_schemas)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#list_schemas)
         """
 
@@ -237,7 +237,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         List of SQL statements.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_statements)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_statements)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#list_statements)
         """
 
@@ -257,14 +257,14 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         List the tables in a database.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_tables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_tables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#list_tables)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_table"]) -> DescribeTablePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#describetablepaginator)
         """
 
@@ -273,34 +273,34 @@ class RedshiftDataAPIServiceClient(BaseClient):
         self, operation_name: Literal["get_statement_result"]
     ) -> GetStatementResultPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#getstatementresultpaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_databases"]) -> ListDatabasesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listdatabasespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_schemas"]) -> ListSchemasPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listschemaspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_statements"]) -> ListStatementsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#liststatementspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tables"]) -> ListTablesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listtablespaginator)
         """
